@@ -75,6 +75,7 @@ return(y)
 #' @export
 ################
 pop.freq<-function(dat,diploid=TRUE){
+  if (is.genind(data)) data<-genind2hierfstat(data)
   lapply(allele.count(dat,diploid),function(x) sweep(x,2,colSums(x,na.rm=TRUE),FUN="/"))
 }
 #########################################################################
@@ -188,7 +189,7 @@ allelic.richness<-function (data, min.n = NULL, diploid = TRUE)
 {
     raref <- function(x) {
         nn <- sum(x)
-        dum <- choose(nn - x, min.n)/choose(nn, min.n)
+        dum <- exp(lchoose(nn - x, min.n)-lchoose(nn, min.n))
         dum[is.na(dum)] <- 0
         return(sum(1 - dum))
     }
